/////////////////////////////////////////////////////////////////////////////
// 15.h: application declaration file


#ifndef __15_H__
#define __15_H__

#include "afxext.h"

#define BORDER_WIDTH	12	// measured in pixels
#define BUTTON_WIDTH	32	// measured in pixels

// Record Macros
#define RECORD_SECTION					"Record"
#define BESTMOVES_BEGINNER				99 
#define BESTPLAYER_BEGINNER				"Unknown"
#define BESTMOVES_BEGINNER_ENTRY		"BestBeginnerMoves"
#define BESTPLAYER_BEGINNER_ENTRY		"BestBeginner"
#define BESTMOVES_INTERMEDIATE			99 
#define BESTPLAYER_INTERMEDIATE			"Unknown"
#define BESTMOVES_INTERMEDIATE_ENTRY	"BestIntermediateMoves"
#define BESTPLAYER_INTERMEDIATE_ENTRY	"BestIntermediate"
#define BESTMOVES_EXPERT				99 
#define BESTPLAYER_EXPERT				"Unknown"
#define BESTMOVES_EXPERT_ENTRY			"BestExpertMoves"
#define BESTPLAYER_EXPERT_ENTRY			"BestExpert"

// Level Macros
#define	BEGINNER			10	// Random Tile Movements
#define INTERMEDIATE    	25
#define EXPERT         		50
#define LEVEL_SECTION		"Level"
#define LEVEL_ENTRY			"LastLevel"
#define DEFAULT_LEVEL		BEGINNER 

// Status Bar Macros
#define BAR_HEIGHT			20	// Measured in Pixels
#define TOP_MARGIN			 2
#define LEFT_MARGIN			 5	

/////////////////////////////////////////////////////////////////////////////

class CMainWindow : public CFrameWnd
{
public:
	CMainWindow();       
	void StartGame();
	
protected:
	void CreateFrame();
	void CreateTiles();
	
	// Board Drawing
	void DrawFrame();
	void DrawTiles();
	void MoveTile(int row, int col, BOOL showMove = TRUE);
	
	// Status Bar
	void DrawStatusBar();
	void UpdateStatusBar();
	
	// Sound
	void Beep(int frequency,int duration);
	void Sleep(clock_t wait);

public:
	// Public Data
	int				m_level;
	int				m_beginnerBestMoves;
	int				m_intermediateBestMoves;
	int				m_expertBestMoves;
	CString			m_beginnerBestPlayer;
	CString			m_intermediateBestPlayer;
	CString			m_expertBestPlayer;

protected:
	// Protected Data
	BOOL			m_sound;
	int				m_moves;
	int				m_gameTile[4][4];
	CBitmapButton*	m_gameArea[6][6];

	//{{AFX_MSG( CMainWindow )
	afx_msg void OnGameNew();
	afx_msg void OnGameExit();
	afx_msg void OnHelpAbout();
	afx_msg void OnHelpRules();
	afx_msg void OnGameLevelBeginner();
	afx_msg void OnGameLevelExpert();
	afx_msg void OnGameLevelIntermediate();
	afx_msg void OnUpdateGameLevelBeginner(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGameLevelExpert(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGameLevelIntermediate(CCmdUI* pCmdUI);
	afx_msg void OnGameHighscores();
	afx_msg void OnGameSoundon();
	afx_msg void OnUpdateGameSoundon(CCmdUI* pCmdUI);
	afx_msg void OnPaint();
	afx_msg void OnHelpOptions();
	afx_msg void OnDestroy();
	//}}AFX_MSG
	
	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
	void UpdateHiScores();
	
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

// CTheApp:
// See hello.cpp for the code to the InitInstance member function.
//
class CTheApp : public CWinApp
{
public:
	BOOL InitInstance();
};

/////////////////////////////////////////////////////////////////////////////

#endif // __15_H__

